==> haskell-arrows-0.4.4.2-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-JBmGDTo1g5J1WozpAjNzf7
key:                  arrows-0.4.4.2-JBmGDTo1g5J1WozpAjNzf7
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  f55f5c29f5b2e228cb63814d4804f034
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.0.1/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/arrows-0.4.4.2
hs-libraries:         HSarrows-0.4.4.2-JBmGDTo1g5J1WozpAjNzf7
depends:              Stream-0.4.7.2-I4kmqayQspG6rnBOlrpTui base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arrows-0.4.4.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-5FJEvyS3bBJFamI2s0rgGN
key:                  arrows-0.4.4.2-5FJEvyS3bBJFamI2s0rgGN
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  9561a255c4af2b308944c61f2931b373
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.0.1/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/arrows-0.4.4.2
hs-libraries:         HSarrows-0.4.4.2-5FJEvyS3bBJFamI2s0rgGN
depends:              Stream-0.4.7.2-12Wm09Wa1In5qkylFB5lcs base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
